=begin

= Events

[((<Index|URL:index.en.html>))
|((<RD format|URL:events.en.rd>))]

The ASP platform allows developers to create Web Applications. In fulfillment 
of real software requirements, ASP allows event-triggered actions to be taken, 
which are defined in a global.asa file. The global.asa file resides in the 
Global directory, defined as a config option, and may define the following 
actions:

  Action              Event
  ------              ------
  script_OnStart *    Beginning of Script execution
  script_OnEnd *      End of Script execution
  application_OnStart Beginning of Application
  application_OnEnd   End of Application
  session_OnStart     Beginning of user Session.
  session_OnEnd       End of user Session.
  
  (*) These are API extensions that are not portable, but were
      added because they are incredibly useful

These actions must be defined in the $Global/global.asa file as subroutines, 
for example:

  def session_OnStart 
      $Application[$Session.sessionID] = started;
  end

Sessions are easy to understand. When visiting a page in a web application, 
each user has one unique $Session. This session expires, after which the user 
will have a new $Session upon revisiting.

A web application starts when the user visits a page in that application, and 
has a new $Session created. Right before the first $Session is created, the 
$Application is created. When the last user $Session expires, that $Application 
expires also. For some web applications that are always busy, the 
application_OnEnd event may never occur.

== script_OnStart & script_OnEnd

The script events are used to run any code for all scripts in an application 
defined by a global.asa. Often, you would like to run the same code for every 
script, which you would otherwise have to add by hand, or add with a file include, 
but with these events, just add your code to the global.asa, and it will be run.

There is one caveat. Code in script_OnEnd is not guaranteed to be run when 
$Response.end() is called, since the program execution ends immediately at this 
event.

== session_OnStart

Triggered by the beginning of a user's session, session_OnStart gets run when  
the user's acces the $Session object for the first time.

The session_OnStart is particularly useful for caching database data, and avoids 
having the caching handled by clumsy code inserted into each script being 
executed.

== session_OnEnd

Triggered by a user session ending, session_OnEnd can be useful for cleaning up 
and analyzing user data accumulated during a session.

Sessions end when the session timeout expires. The timing of the session_OnEnd 
occur immediately after the session times out.

Thus I would not put anything mission-critical in the session_OnEnd, just stuff 
that would be nice to run whenever it gets run.

== application_OnStart

TODO

This event marks the beginning of an ASP application, and is run just before the 
session_OnStart of the first Session of an application. This event is useful to 
load up $Application with data that will be used in all user sessions.

== application_OnEnd

TODO

The end of the application is marked by this event, which is run after the last 
user session has timed out for a given ASP application.

[((<Back to Index|Events>))]

=end
